@@ -28,13 +28,13 @@
 
 #include <kconfiggroup.h>
 
-#include <QtCore/QFile>
-#include <QtCore/QMap>
-#include <QtCore/QTextStream>
-#include <QtCore/QSharedData>
-#include <QtCore/QStandardPaths>
-#include <QtCore/QLocale>
-#include <QtCore/QDataStream>
+#include <QFile>
+#include <QMap>
+#include <QTextStream>
+#include <QSharedData>
+#include <QStandardPaths>
+#include <QLocale>
+#include <QDataStream>
 
 using namespace KContacts;
 
@@ -136,7 +136,7 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
     // The following macro needs QString for R_FIELD
     // It substitutes !_P_! for empty fields so conditional tags work later
 #define REPLTAG(R_TAG,R_FIELD) \
-    if ( result.indexOf( R_TAG ) != -1 ) { \
+    if ( result.contains( R_TAG ) ) { \
         QString rpl = R_FIELD.isEmpty() ? QStringLiteral( "!_P_!" ) : R_FIELD; \
         result.replace( R_TAG, rpl ); \
         if ( !R_FIELD.isEmpty() ) { \
@@ -560,9 +560,7 @@ Geo Address::geo() const
 
 QString Address::toString() const
 {
-    QString str;
-
-    str += QLatin1String("Address {\n");
+    QString str = QLatin1String("Address {\n");
     str += QStringLiteral("  IsEmpty: %1\n").
            arg(d->mEmpty ? QStringLiteral("true") : QStringLiteral("false"));
     str += QStringLiteral("  Id: %1\n").arg(d->mId);
